<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru_RU" sourcelanguage="en" version="2.1">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/qtwrapper/callmanager_wrap.h" line="393"/>
        <source>Me</source>
        <translation>Мне</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="61"/>
        <source>Hold</source>
        <translation>Удержание</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="63"/>
        <source>Talking</source>
        <translation>Говорить</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="65"/>
        <source>ERROR</source>
        <translation>ОШИБКА</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="67"/>
        <source>Incoming</source>
        <translation>Входящий</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="69"/>
        <source>Calling</source>
        <translation>звонящий</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="71"/>
        <location filename="../src/chatview.cpp" line="72"/>
        <source>Connecting</source>
        <translation>Подключение</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="73"/>
        <source>Searching</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="75"/>
        <source>Inactive</source>
        <translation>Неактивный</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="77"/>
        <location filename="../src/api/call.h" line="83"/>
        <location filename="../src/chatview.cpp" line="79"/>
        <source>Finished</source>
        <translation>Завершено</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="79"/>
        <source>Timeout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/call.h" line="81"/>
        <source>Peer busy</source>
        <translation>Абонент занят</translation>
    </message>
    <message>
        <location filename="../src/api/call.h" line="85"/>
        <source>Communication established</source>
        <translation>Соединение установлено</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="218"/>
        <location filename="../src/authority/storagehelper.cpp" line="136"/>
        <location filename="../src/authority/storagehelper.cpp" line="954"/>
        <source>Invitation received</source>
        <translation>Получено приглашение</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="222"/>
        <source>Contact left conversation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="216"/>
        <location filename="../src/authority/storagehelper.cpp" line="133"/>
        <location filename="../src/authority/storagehelper.cpp" line="952"/>
        <source>Contact added</source>
        <translation>Контакт добавлен</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="110"/>
        <location filename="../src/authority/storagehelper.cpp" line="116"/>
        <location filename="../src/authority/storagehelper.cpp" line="950"/>
        <source>Outgoing call</source>
        <translation>Исходящий вызов</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="112"/>
        <location filename="../src/authority/storagehelper.cpp" line="122"/>
        <source>Incoming call</source>
        <translation>Входящий вызов</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="118"/>
        <location filename="../src/authority/storagehelper.cpp" line="948"/>
        <source>Missed outgoing call</source>
        <translation>Пропущенный исходящий</translation>
    </message>
    <message>
        <location filename="../src/authority/storagehelper.cpp" line="124"/>
        <source>Missed incoming call</source>
        <translation>Пропущенный входящий</translation>
    </message>
    <message>
        <location filename="../src/api/interaction.h" line="220"/>
        <location filename="../src/authority/storagehelper.cpp" line="138"/>
        <location filename="../src/authority/storagehelper.cpp" line="956"/>
        <source>Invitation accepted</source>
        <translation>Приглашение принято</translation>
    </message>
    <message>
        <location filename="../src/avmodel.cpp" line="339"/>
        <location filename="../src/avmodel.cpp" line="358"/>
        <source>default</source>
        <translation>по-умолчанию</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="55"/>
        <source>Null</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="56"/>
        <source>Trying</source>
        <translation>Пытаемся</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="57"/>
        <source>Ringing</source>
        <translation>Вызов</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="58"/>
        <source>Being Forwarded</source>
        <translation>Будет перенаправлено</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="59"/>
        <source>Queued</source>
        <translation>В очереди</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="60"/>
        <source>Progress</source>
        <translation>Вызов</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="61"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="73"/>
        <location filename="../src/newcallmodel.cpp" line="62"/>
        <source>Accepted</source>
        <translation>Принято</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="63"/>
        <source>Multiple Choices</source>
        <translation>Множественный выбор</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="64"/>
        <source>Moved Permanently</source>
        <translation>Перемещено навсегда</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="65"/>
        <source>Moved Temporarily</source>
        <translation>Временно перемещено</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="66"/>
        <source>Use Proxy</source>
        <translation>Использовать прокси</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="67"/>
        <source>Alternative Service</source>
        <translation>Альтернативный сервис</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="68"/>
        <source>Bad Request</source>
        <translation>Неверный запрос</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="69"/>
        <source>Unauthorized</source>
        <translation>Неавторизовано</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="70"/>
        <source>Payment Required</source>
        <translation>Требуется оплата</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="71"/>
        <source>Forbidden</source>
        <translation>Запрещено</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="72"/>
        <source>Not Found</source>
        <translation>Не найдено</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="73"/>
        <source>Method Not Allowed</source>
        <translation>Метод не поддерживается</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="74"/>
        <location filename="../src/newcallmodel.cpp" line="94"/>
        <source>Not Acceptable</source>
        <translation>Не принято</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="75"/>
        <source>Proxy Authentication Required</source>
        <translation>Требуется аутентификация</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="76"/>
        <source>Request Timeout</source>
        <translation>Время ожидания запроса</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="77"/>
        <source>Gone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="78"/>
        <source>Request Entity Too Large</source>
        <translation>Запрос слишком большой</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="79"/>
        <source>Request URI Too Long</source>
        <translation>Запрошенный URI слишком большой</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="80"/>
        <source>Unsupported Media Type</source>
        <translation>Неподдерживаемый тип медиа</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="81"/>
        <source>Unsupported URI Scheme</source>
        <translation>Неподдерживаемая схема данных</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="82"/>
        <source>Bad Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="83"/>
        <source>Extension Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="84"/>
        <source>Session Timer Too Small</source>
        <translation>Таймер сессии слишком мал</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="85"/>
        <source>Interval Too Brief</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="86"/>
        <source>Temporarily Unavailable</source>
        <translation>Временно недоступно</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="87"/>
        <source>Call TSX Does Not Exist</source>
        <translation>Вызываемый TSX не существует</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="88"/>
        <source>Loop Detected</source>
        <translation>Всё зациклилось</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="89"/>
        <source>Too Many Hops</source>
        <translation>Слишком много прыжков</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="90"/>
        <source>Address Incomplete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="91"/>
        <source>Ambiguous</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="92"/>
        <source>Busy</source>
        <translation>Занят</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="93"/>
        <source>Request Terminated</source>
        <translation>Запрос прерван</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="95"/>
        <source>Bad Event</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="96"/>
        <source>Request Updated</source>
        <translation>Запрос обновлён</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="97"/>
        <source>Request Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="98"/>
        <source>Undecipherable</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="99"/>
        <source>Internal Server Error</source>
        <translation>Внутренняя ошибка сервера</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="100"/>
        <source>Not Implemented</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="101"/>
        <source>Bad Gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="102"/>
        <source>Service Unavailable</source>
        <translation>Сервис недоступен</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="103"/>
        <source>Server Timeout</source>
        <translation>Сервер не отвечает</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="104"/>
        <source>Version Not Supported</source>
        <translation>Версия не поддерживается</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="105"/>
        <source>Message Too Large</source>
        <translation>Сообщение слишком большое</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="106"/>
        <source>Precondition Failure</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="107"/>
        <source>Busy Everywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="108"/>
        <source>Call Refused</source>
        <translation>Звонок сброшен</translation>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="109"/>
        <source>Does Not Exist Anywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/newcallmodel.cpp" line="110"/>
        <source>Not Acceptable Anywhere</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="30"/>
        <source>Hide chat view</source>
        <translation>Скрыть чат</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="31"/>
        <source>Place video call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="32"/>
        <source>Show available plugins</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="33"/>
        <source>Place audio call</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="34"/>
        <source>Add to conversations</source>
        <translation>Добавить к контактам</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="35"/>
        <source>Unban contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="36"/>
        <source>Send</source>
        <translation>Отправть</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="37"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="38"/>
        <source>Jump to latest</source>
        <translation>Перейти к последнему</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="39"/>
        <source>Send file</source>
        <translation>Отправить файл</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="40"/>
        <source>Add emoji</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="41"/>
        <source>Leave video message</source>
        <translation>Оставить видеосообщение</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="42"/>
        <source>Leave audio message</source>
        <translation>Оставить аудио сообщение</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="44"/>
        <source>Copy to downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="45"/>
        <source>Write to {0}</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="50"/>
        <source>has sent you a conversation request.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="52"/>
        <source>Hello, do you want to join the conversation?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="54"/>
        <source>You have accepted the conversation request.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="56"/>
        <source>We are waiting for another device to synchronize the conversation.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="67"/>
        <source>Accept</source>
        <translation>Принять</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="68"/>
        <source>Refuse</source>
        <translation>Отказать</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="71"/>
        <source>Unable to make contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="76"/>
        <source>Waiting for contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="77"/>
        <source>Incoming transfer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="78"/>
        <source>Timed out waiting for contact</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="43"/>
        <source>Block</source>
        <translation>Заблокировать</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="47"/>
        <source>Note: an interaction will create a new contact.</source>
        <translation>Справка: будет создан новый контакт.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="48"/>
        <source>is not in your contacts</source>
        <translation>нет в ваших контактах</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="58"/>
        <source>Note: you can automatically accept this invitation by sending a message.</source>
        <translation>Справка: вы можете автоматически принять это приглашение отправив сообщение.</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>{0} days ago</source>
        <translation>{0} дней назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>{0} hours ago</source>
        <translation>{0} часов назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>{0} minutes ago</source>
        <translation>{0} минут назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="74"/>
        <source>Canceled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="75"/>
        <source>Ongoing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="59"/>
        <source>%d days ago</source>
        <translation>%d дней назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="60"/>
        <source>%d hours ago</source>
        <translation>%d часов назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="62"/>
        <source>%d minutes ago</source>
        <translation>%d минут  назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="63"/>
        <source>one day ago</source>
        <translation>вчера</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="64"/>
        <source>one hour ago</source>
        <translation>час назад</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="65"/>
        <source>just now</source>
        <translation>только что</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="66"/>
        <source>Failure</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="69"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/chatview.cpp" line="70"/>
        <source>Retry</source>
        <translation>Повтор</translation>
    </message>
</context>
<context>
    <name>lrc::ContactModelPimpl</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="474"/>
        <source>Searching…</source>
        <translation>Поиск...</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="999"/>
        <source>Invalid ID</source>
        <translation>Неверный ID</translation>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1002"/>
        <source>Username not found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/contactmodel.cpp" line="1005"/>
        <source>Couldn&apos;t lookup…</source>
        <translation>Невозможно найти...</translation>
    </message>
</context>
<context>
    <name>lrc::api::ContactModel</name>
    <message>
        <location filename="../src/contactmodel.cpp" line="435"/>
        <source>Bad URI scheme</source>
        <translation>Неверная схема URI</translation>
    </message>
</context>
</TS>